Conveniently set qpmad parameters. Please always use named arguments since parameters can change without notice between releases. In a future version specifying the argument names will be mandatory.
qpmadParameters(
isFactorized = FALSE,
maxIter = -1,
tol = 1e-12,
checkPD = TRUE,
factorizationType = "NONE",
withLagrMult = FALSE,
returnInvCholFac = FALSE
)Deprecated, will be removed in a future version. Please use factorizationType instead. If
TRUE then H is a lower Cholesky factor, overridden byfactorizationType.
Maximum number of iterations, if not positive then no limit.
Convergence tolerance.
Deprecated. Ignored, will be removed in a future release.
IF "NONE" then H is a Hessian (default), if "CHOLESKY" then H is
a (lower) cholesky factor. If "INV_CHOLESKY" then H is the inverse of a cholesky factor, i.e. such that
the Hessian is given by inv(HH').
If TRUE then the Lagrange multipliers of the inequality constraints, along with their
indexes and an upper / lower side indicator, will be returned.
If TRUE then also return the inverse Cholesky factor of the Hessian.
a list suitable to be used as the pars-argument to solveqp
# NOT RUN {
qpmadParameters(withLagrMult = TRUE)
# }
Run the code above in your browser using DataLab